Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS SSO Directory.

Actions, resources, and condition keys for AWS SSO Directory - Service Authorization Reference

# Actions, resources, and condition keys for AWS SSO Directory

AWS SSO Directory (service prefix: `sso-directory` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS SSO Directory
- Resource types defined by AWS SSO Directory
- Condition keys for AWS SSO Directory

## Actions defined by AWS SSO Directory

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddMemberToGroup | Grants permission to add a member to a group in the directory that AWS SSO provides by default | Write |  |  |
CompleteVirtualMfaDeviceRegistration | Grants permission to complete the creation process of a virtual MFA device | Write |  |  |
CompleteWebAuthnDeviceRegistration | Grants permission to complete the registration process of a WebAuthn device | Write |  |  |
CreateAlias | Grants permission to create an alias for the directory that AWS SSO provides by default | Write |  |  |
CreateBearerToken | Grants permission to create a bearer token for a given provisioning tenant | Write |  |  |
CreateExternalIdPConfigurationForDirectory | Grants permission to create an External Identity Provider configuration for the directory | Write |  |  |
CreateGroup | Grants permission to create a group in the directory that AWS SSO provides by default | Write |  |  |
CreateProvisioningTenant | Grants permission to create a provisioning tenant for a given directory | Write |  |  |
CreateUser | Grants permission to create a user in the directory that AWS SSO provides by default | Write |  |  |
DeleteBearerToken | Grants permission to delete a bearer token | Write |  |  |
DeleteExternalIdPCertificate | Grants permission to delete the given external IdP certificate | Write |  |  |
DeleteExternalIdPConfigurationForDirectory | Grants permission to delete an External Identity Provider configuration associated with the directory | Write |  |  |
DeleteGroup | Grants permission to delete a group from the directory that AWS SSO provides by default | Write |  |  |
DeleteMfaDeviceForUser | Grants permission to delete a MFA device by device name for a given user | Write |  |  |
DeleteProvisioningTenant | Grants permission to delete the provisioning tenant | Write |  |  |
DeleteUser | Grants permission to delete a user from the directory that AWS SSO provides by default | Write |  |  |
DescribeDirectory | Grants permission to retrieve information about the directory that AWS SSO provides by default | Read |  |  |
DescribeGroup | Grants permission to query the group data, not including user and group members | Read |  |  |
DescribeGroups | Grants permission to retrieve information about groups from the directory that AWS SSO provides by default | Read |  |  |
DescribeProvisioningTenant | Grants permission to describes the provisioning tenant | Read |  |  |
DescribeUser | Grants permission to retrieve information about a user from the directory that AWS SSO provides by default | Read |  |  |
DescribeUserByUniqueAttribute | Grants permission to describe user with a valid unique attribute represented for the user | Read |  |  |
DescribeUsers | Grants permission to retrieve information about user from the directory that AWS SSO provides by default | Read |  |  |
DisableExternalIdPConfigurationForDirectory | Grants permission to disable authentication of end users with an External Identity Provider | Write |  |  |
DisableUser | Grants permission to deactivate a user in the directory that AWS SSO provides by default | Write |  |  |
EnableExternalIdPConfigurationForDirectory | Grants permission to enable authentication of end users with an External Identity Provider | Write |  |  |
EnableUser | Grants permission to activate user in the directory that AWS SSO provides by default | Write |  |  |
GetAWSSPConfigurationForDirectory | Grants permission to retrieve the AWS SSO Service Provider configurations for the directory | Read |  |  |
GetUserPoolInfo | Grants permission to get UserPool Info | Read |  |  |
ImportExternalIdPCertificate | Grants permission to import the IdP certificate used for verifying external IdP responses | Write |  |  |
IsMemberInGroup | Grants permission to check if a member is a part of the group in the directory that AWS SSO provides by default | Read |  |  |
ListBearerTokens | Grants permission to list bearer tokens for a given provisioning tenant | Read |  |  |
ListExternalIdPCertificates | Grants permission to list the external IdP certificates of a given directory and IdP | Read |  |  |
ListExternalIdPConfigurationsForDirectory | Grants permission to list all the External Identity Provider configurations created for the directory | Read |  |  |
ListGroupsForMember | Grants permission to list groups of the target member | Read |  |  |
ListGroupsForUser | Grants permission to list groups for a user from the directory that AWS SSO provides by default | Read |  |  |
ListMembersInGroup | Grants permission to retrieve all members that are part of a group in the directory that AWS SSO provides by default | Read |  |  |
ListMfaDevicesForUser | Grants permission to list all active MFA devices and their MFA device metadata for a user | Read |  |  |
ListProvisioningTenants | Grants permission to list provisioning tenants for a given directory | Read |  |  |
RemoveMemberFromGroup | Grants permission to remove a member that is part of a group in the directory that AWS SSO provides by default | Write |  |  |
SearchGroups | Grants permission to search for groups within the associated directory | Read |  |  |
SearchUsers | Grants permission to search for users within the associated directory | Read |  |  |
StartVirtualMfaDeviceRegistration | Grants permission to begin the creation process of virtual mfa device | Write |  |  |
StartWebAuthnDeviceRegistration | Grants permission to begin the registration process of a WebAuthn device | Write |  |  |
UpdateExternalIdPConfigurationForDirectory | Grants permission to update an External Identity Provider configuration associated with the directory | Write |  |  |
UpdateGroup | Grants permission to update information about a group in the directory that AWS SSO provides by default | Write |  |  |
UpdateGroupDisplayName | Grants permission to update group display name update group display name response | Write |  |  |
UpdateMfaDeviceForUser | Grants permission to update MFA device information | Write |  |  |
UpdatePassword | Grants permission to update a password by sending password reset link via email or generating one time password for a user in the directory that AWS SSO provides by default | Write |  |  |
UpdateUser | Grants permission to update user information in the directory that AWS SSO provides by default | Write |  |  |
UpdateUserName | Grants permission to update user name update user name response | Write |  |  |
VerifyEmail | Grants permission to verify an email address of an User | Write |  |  |

## Resource types defined by AWS SSO Directory

AWS SSO Directory does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to AWS SSO Directory, specify `“Resource”: “*”` in your policy.

## Condition keys for AWS SSO Directory

SSO Directory has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.